<?php

namespace Drupal\readonly_html_field\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a widget of readonly html field.
 *
 * @FieldWidget(
 *   id = "readonly_html_field_widget",
 *   label = @Translation("Readonly Html Field Widget"),
 *   field_types = {"readonly_html_field"}
 * )
 */
class ReadonlyHtmlFieldWidget extends WidgetBase {

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $default_langcode = \Drupal::languageManager()->getDefaultLanguage()->getId();
    $default_readonly_html = $this->fieldDefinition->getSetting($default_langcode)['readonly_html']['value'];
    $readonly_html = $this->fieldDefinition->getSetting($langcode)['readonly_html']['value'];
    $element = [
      '#markup' => !empty($readonly_html) ? $readonly_html : $default_readonly_html,
    ];
    return $element;
  }

  /**
   * {@inheritDoc}
   */
  public function formMultipleElements(FieldItemListInterface $items, array &$form, FormStateInterface $form_state) {
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $default_langcode = \Drupal::languageManager()->getDefaultLanguage()->getId();
    $default_readonly_html = $this->fieldDefinition->getSetting($default_langcode)['readonly_html']['value'];
    $readonly_html = $this->fieldDefinition->getSetting($langcode)['readonly_html']['value'];
    $element = [
      '#markup' => !empty($readonly_html) ? $readonly_html : $default_readonly_html,
    ];
    return $element;
  }

}
